# coding=ISO-8859-1
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Components.config import *
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ConfigList import ConfigList, ConfigListScreen
from Components.MenuList import MenuList
from Components.Button import Button
from Components.NimManager import nimmanager
from Components.Label import Label
from Components.Pixmap import Pixmap
from enigma import eTimer
from Screens.Standby import TryQuitMainloop
from Plugins.Extensions.LcdDigital.xmltools import *
from Components.config import config

import os
import gettext
try:
	cat = gettext.translation('lang', '/usr/lib/enigma2/python/Plugins/Extensions/LcdDigital/po', [config.osd.language.getText()])
	_ = cat.gettext
except IOError:
	pass

class LcdDigitalSetup(Screen, ConfigListScreen):
	
	def __init__(self, session):
		self.skin = """
		<screen name="LcdDigitalSetup" position="165,110" size="800,380" title="LCD-Digital-Skin">
			<widget name="config" position="5,10" size="780,320"  scrollbarMode="showOnDemand" />
			<widget name="ok" position="90,340" size="53,40" pixmap="skin_default/buttons/green.png" alphatest="on" />
			<widget name="oktext" position="90,340" size="53,40" valign="center" halign="center" zPosition="1" font="Regular;20" backgroundColor="#1f771f" transparent="1" />
			<widget name="cancel" position="190,340" size="100,40" pixmap="skin_default/buttons/red.png" alphatest="on" />
			<widget name="canceltext" position="190,340" size="100,40" valign="center" halign="center" zPosition="1" font="Regular;20" backgroundColor="#1f771f" transparent="1" />
		</screen>"""
		Screen.__init__(self, session)
		self.session = session

		self.skins = {}

		self["oktext"] = Label(_("OK"))
		self["canceltext"] = Label(_("Cancel"))
		self["ok"] = Pixmap()
		self["cancel"] = Pixmap()

		self.LoadConfig()
		self.createConfig()

		self["actions"] = NumberActionMap(["SetupActions", "TextEntryActions"],
		{
			"ok": self.keySelect,
			"save": self.keyGo,
			"cancel": self.keyCancel,
			"left": self.keyLeft,
			"right": self.keyRight,
			"delete": self.keyDelete,
			"1": self.keyNumberGlobal,
			"2": self.keyNumberGlobal,
			"3": self.keyNumberGlobal,
			"4": self.keyNumberGlobal,
			"5": self.keyNumberGlobal,
			"6": self.keyNumberGlobal,
			"7": self.keyNumberGlobal,
			"8": self.keyNumberGlobal,
			"9": self.keyNumberGlobal,
			"0": self.keyNumberGlobal
		}, -1)

		self.list = []
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changedEntry)
		self.createSetup("config")

	def changedEntry(self):
		if (self.skinname != self.lcd_skin.value):
			self.skinname = self.lcd_skin.value
			self.skinfile = self.skinname + ".xml"
			self.createSetup("config")

	def ReadLine(self,f):
		s = f.readline()
		s = str(buffer(s,0,len(s)-1))
		return s
			
	def XMLToChoice(self,on):
		con = _("off")
		if (on == ON):
			con = _("on")
		return con
			
	def ChoiceToXML(self,on):
		con = OFF
		if (on == _("on")):
			con = ON
		return con
						
	def LoadConfig(self):
		CheckSkins()
		self.on = self.XMLToChoice(GetSetupAttrib(SETUP,"plugin"))
		self.skinfile = GetSetupAttrib(SETUP,"skin")
		self.skinname = self.skinfile[0:self.skinfile.find(".")]
		self.size = int(GetSetupAttrib(SETUP,"size"))
		self.len = int(GetSetupAttrib(SETUP,"len"))
		self.logo = self.XMLToChoice(GetSetupAttrib(SETUP,"logoinfobox"))

	def createConfig(self):
		self.lcd_on = ConfigSelection(default = self.on, choices = [_("off"),_("on")])
		self.lcd_skin = ConfigSelection(default = self.skinname, choices = GetSetupScreenList())
		self.lcd_len = ConfigInteger(default = self.len, limits=(0,999))
		self.lcd_size = ConfigInteger(default = self.size, limits=(0,999))
		self.lcd_logo = ConfigSelection(default = self.logo, choices = [_("off"),_("on")])
		
	def createSetup(self, widget):
		self.list = []
		self.list.append(getConfigListEntry(_("LcdDigital-Plugin (on/off):"), self.lcd_on))
		self.list.append(getConfigListEntry(_("Switch on/off infobar picon:"), self.lcd_logo))
		self.list.append(getConfigListEntry(_("Skin:"), self.lcd_skin))
		self.list.append(getConfigListEntry(_("Length of the channeltext:"), self.lcd_len))
		self.list.append(getConfigListEntry(_("Size of the channeltext:"), self.lcd_size))
		if (self.skins.has_key(self.skinfile)):
			screens = self.skins[self.skinfile]
			for s,s_on in screens.items():
				self.list.append(getConfigListEntry(s + ":", s_on))
		else:
			screensdef = {}
			screenson = {}
			fonts = {}
			ReadSkins(self.skinfile,screensdef,fonts)
			ReadScreensOn(self.skinfile,screensdef,screenson)
			screens = {}
			for s,o in screenson.items():
				s_on = ConfigSelection(default = self.XMLToChoice(o), choices = [_("off"),_("on")])
				screens[s] = s_on
				self.list.append(getConfigListEntry(s + ":", s_on))
			self.skins[self.skinfile] = screens
		self[widget].list = self.list
		self[widget].l.setList(self.list)

	def keySelect(self):
		self.keyGo()

	def keyGo(self):
		SetSetupAttrib(SETUP,"plugin",self.ChoiceToXML(self.lcd_on.value))
		SetSetupAttrib(SETUP,"skin",self.skinfile)
		SetSetupAttrib(SETUP,"size",str(self.lcd_size.value))
		SetSetupAttrib(SETUP,"len",str(self.lcd_len.value))
		SetSetupAttrib(SETUP,"logoinfobox",self.ChoiceToXML(self.lcd_logo.value))
		document = xml.etree.cElementTree.parse(SETUP)
		for sf,sc in self.skins.items():
			for s,s_on in sc.items():
				SetSkin(document,sf,s,self.ChoiceToXML(s_on.value))
		Write(SETUP,document);
		self.session.openWithCallback(self.restart,MessageBox,_("GUI needs a restart to apply the new LCD-Digital-Skin configuration. Do you want to restart the GUI now ?"), MessageBox.TYPE_YESNO)

	def restart(self, answer):
		if answer is True:
			self.session.open(TryQuitMainloop, 3)
		else:
			self.close((True,))
 
	def keyCancel(self):
		self.close((False,))
