import xml.etree.cElementTree
import os
import sys

ON = "on"
OFF = "off"
SETUP="/etc/enigma2/LcdDigital.xml"
SKINDIR="/usr/share/enigma2/LcdDigital/LcdDigitalSkins"

class LcdDigitalConfig:
	value = 0

LcdDigital = LcdDigitalConfig()

def init(setup):
	setup.attrib["size"] = "90"
	setup.attrib["len"] = "0"
	setup.attrib["skin"] = "LcdDigital.xml"
	setup.attrib["plugin"] = ON
	setup.attrib["logoinfobox"] = ON

def ReadSkins(file,screens,fonts):
	filename = SKINDIR + "/" + file
	if (os.path.isfile(filename)):
	
		document = xml.etree.cElementTree.parse(filename)
		root = document.getroot()

		for basisskin in root.findall("basisskin"):
			ReadSkins(basisskin.attrib["name"],screens,fonts)
	
		for screen in root.findall("screen"):
			screens[ screen.attrib["name"] ] = screen

		for c in root.findall("fonts"):
			for font in c.findall("font"):
				file = str(font.attrib["filename"] or "<NONAME>")
				name = str(font.attrib["name"] or "Regular")
				scale = int(font.attrib["scale"] or "100")
				try:
					is_replacement = font.attrib["replacement"] != ""
				except KeyError:
					is_replacement = False
				fonts[name] = (file,scale,is_replacement)
	else:
		SetSetupAttrib(SETUP,"skin","LcdDigital.xml")

def Update():
	if (os.path.isfile(SETUP)):
		document = xml.etree.cElementTree.parse(SETUP)
		root = document.getroot()
		setup = Find(root,"setup")
		flag = False
		try:
			test = setup.attrib["size"]
		except KeyError:
			flag = True
			setup.attrib["size"] = "90"
		try:
			test = setup.attrib["len"]
		except KeyError:
			flag = True
			setup.attrib["len"] = "0"
		try:
			test = setup.attrib["skin"] 
		except KeyError:
			flag = True
			setup.attrib["skin"] = "LcdDigital.xml"
		try:
			test = setup.attrib["plugin"] 
		except KeyError:
			flag = True
			setup.attrib["plugin"] = ON
		try:
			test = setup.attrib["logoinfobox"]
		except KeyError:
			flag = True
			setup.attrib["logoinfobox"] = ON
		if flag:
			document.write(SETUP)
	
	
def Write(filename,document):
	document.write(filename);

def Find(Elm,Tag):
	if Elm.tag == Tag:
		return Elm
	else:
		return Elm.Tag

def GetSetupAttrib(filename,name,tag = "setup"):
	document = xml.etree.cElementTree.parse(filename)
	root = document.getroot()
	setup = Find(root,tag)
	return setup.attrib[name]

def SetSetupAttrib(filename,name,value,tag = "setup"):
	document = xml.etree.cElementTree.parse(filename)
	root = document.getroot()
	setup = Find(root,tag)
	setup.attrib[name] = value
	Write(filename,document)
	
def SetSkin(document,filename,name,on):
	root = document.getroot()
	setup = Find(root,"setup")
	for skin in setup.findall("skin"):
		if (skin.attrib["file"] == filename):
			for screen in skin.findall("screen"):
				if (screen.attrib["name"] == name):
					print filename,name,on
					screen.attrib[ON] = on				
				
def GetSetupScreenList():
	list = []
	document = xml.etree.cElementTree.parse(SETUP)
	root = document.getroot()
	setup = Find(root,"setup")
	for skin in setup.findall("skin"):
		file = str(skin.attrib["file"])
		file = file[0:file.find(".")]
		list.append(file)
	return list

def NewSkin(Doc,skinname,setup,screenson,screens):
	skin = xml.etree.cElementTree.Element("skin");
	skin.attrib["file"] = skinname
	for name,screen in screens.items():
		screen = xml.etree.cElementTree.Element("screen");
		screen.attrib["name"] = name
		screen.attrib[ON] = ON
		screenson[name] = ON
		skin.append(screen);
	root = Doc.getroot()
	setup = Find(root,"setup")
	setup.append(skin);
			
def CleanSetup(xmls):
	if (os.path.isfile(SETUP)):
		document = xml.etree.cElementTree.parse(SETUP)
		root = document.getroot()
		setup = Find(root,"setup")
		for skin in setup.findall("skin"):
			file = skin.attrib["file"]
			if file not in xmls:
				setup.remove(skin)
		Write(SETUP,document)
			
def ReadScreensOn(skinname,screens,screenson):
	filename = SETUP
	if (os.path.isfile(filename)):
		document = xml.etree.cElementTree.parse(filename)
		root = document.getroot()
		setup = Find(root,"setup")
		flag = True
		for skin in setup.findall("skin"):
			if (skin.attrib["file"] == skinname):
				for screentag in skin.findall("screen"):
					screenson[screentag.attrib["name"]] = screentag.attrib[ON]
				flag = False
				for name,screen in screens.items():
					if (not(screenson.has_key(name))):
						screenson[ name ] = ON
						screentag = xml.etree.cElementTree.Element("screen");
						screentag.attrib["name"] = name
						screentag.attrib[ON] = ON
						skin.append(screentag);
						Write(filename,document);
				for name,on in screenson.items():
					if (not(screens.has_key(name))):
						for screen in skin.findall("screen"):
							if (screen.attrib["name"] == name):
								skin.remove(screen)
						del screenson[name]
						Write(filename,document);
				break;
		if flag:
			NewSkin(document,skinname,setup,screenson,screens)
			Write(filename,document);
	else:
		setup = xml.etree.cElementTree.Element("setup");
		init(setup)
		document = xml.etree.cElementTree.ElementTree(setup)
		NewSkin(document,skinname,setup,screenson,screens)
		Write(filename,document);

def MakeDoc(screen):
	skin = xml.etree.cElementTree.Element("skin")
	skin.append(screen)
	return skin

def CheckSkins():
	xmls = []
	dirs = os.listdir(SKINDIR)
	for dir in dirs:
		if (dir.find(".xml") > 0):
			path = SKINDIR + "/" + dir
			if (GetSetupAttrib(path,ON,"skin") == ON):
				xmls.append(dir)
	CleanSetup(xmls)
	for dir in xmls:
		screens = {}
		screenson = {}
		fonts = {}
		ReadSkins(dir,screens,fonts)
		ReadScreensOn(dir,screens,screenson)
